/* $Id: GBK-utils.h,v 1.3 2005/05/23 06:41:05 zlb Exp $ */

typedef enum {
	/*GBK_RAW,*/	/* raw GBK code (unimplemented) */
	GBK_PINYIN,	/* Pin yin separate from ASCII chars */
	GBK_STROKE,	/* Strokes (# of strokes followed by strokes seq.) */
	GBK_MIXED,	/* Pin yin mixed with ASCII chars */
	/*GBK_UNICODE*/	/* Unicode <=> ףthen strokes (unimplemented) */
} GBK_order_t;

int GBK_set_ordering(GBK_order_t order);
GBK_order_t GBK_get_ordering(void);
int GBK_char_comp(const unsigned char *gbk1, const unsigned char *gbk2);
void GBK_get_initial(unsigned char *buffer, size_t buffersize,
		const unsigned char *gbk);
